@@ -8,6 +8,7 @@ use 5.008001;
 use Moose;
 use Moose::Exporter;
 use Array::Unique;
+use Hash::Flatten;
 
     Moose::Exporter->setup_import_methods(
         as_is  => [ 'field', 'mixin', 'filter', 'directive' ],
@@ -19,7 +20,8 @@ our $MIXINS     = {};
 our $DIRECTIVES = {};
 our $FILTERS    = {};
 
-our $VERSION = '1.112570'; # VERSION
+our $VERSION = '1.112870'; # VERSION
+
 
 
 
@@ -391,6 +393,11 @@ has 'directives' => (
 sub BUILD {
     my $self = shift;
     
+    # automatically serialize params if nested hash detected
+    if (grep { ref($_) } values %{$self->params}) {
+        $self->set_params_hash($self->params);
+    }
+    
     # reset fields if applicable
     $self->reset_fields();
     
@@ -537,6 +544,34 @@ has 'report_unknown' => (
 );
 
 
+# nested hashref serializer
+has 'hash_inflator' => (
+    is      => 'rw',
+    isa     => 'HashRef'
+);
+
+around 'hash_inflator' => sub {
+    my $orig    = shift;
+    my $self    = shift;
+    my $options = shift || {
+        hash_delimiter  => '.',
+        array_delimiter => ':',
+        escape_sequence => '',
+    };
+    
+    foreach my $option (keys %{$options}) {
+        if ($option =~ /\_/) {
+            my $cc_option = $option;
+            $cc_option =~ s/([a-zA-Z])\_([a-zA-Z])/$1\u$2/gi;
+            $options->{ucfirst $cc_option} = $options->{$option};
+            delete $options->{$option};
+        }
+    }
+
+    return $self->$orig($options);
+};
+
+
 # input parameters store
 has 'params' => (
     is      => 'rw',
@@ -832,32 +867,6 @@ sub validate {
     return @{ $self->{errors} } ? 0 : 1;    # returns true if no errors
 }
 
-
-sub validate_groups {
-    my ($self, @groups) = @_;
-    my %groups = scalar @groups % 2 ? ($groups[0], undef) : @groups;
-    my @fields = ();
-    
-    while (my($key, $value) = each(%groups)) {
-        if ("ARRAY" eq ref $value) {
-            push @fields, "$key:$_" for @{$value};
-        }
-        else {
-            if ($key) {
-                my @values = ();
-                for (keys %{$self->params}) {
-                    push @values, $_ =~ m/$key\:(\w+)/;
-                }
-                if (@values) {
-                    push @fields, "$key:$_" for @values;
-                }
-            }
-        }
-    }
-    
-    return @fields ? $self->validate(@fields) : 0;
-}
-
 sub use_validator {
     my ( $self, $field, $this ) = @_;
 
@@ -920,32 +929,32 @@ sub reset_fields {
 
 
 
-sub get_group_params {
-    my ($self, $group, @params) = @_;
-    return +{} unless $group;
-    
-    unless (@params) {
-        for (keys %{$self->params}) {
-            push @params, $_ =~ m/$group\:(\w+)/;
-        }
-    }
-    
-    return +{
-        map {
-            $_ => $self->params->{"$group:$_"}
-        }   @params
-    };
-}
-
-
 sub get_params {
     my ($self, @params) = @_;
+    
     return map {
         $self->params->{$_}
     }   @params;
 }
 
 
+sub get_params_hash {
+    my ($self) = @_;
+    my $serializer = Hash::Flatten->new($self->hash_inflator);
+    my $params = $serializer->unflatten($self->params);
+    
+    return $params;
+}
+
+
+sub set_params_hash {
+    my ($self, $params) = @_;
+    my $serializer = Hash::Flatten->new($self->hash_inflator);
+    
+    return $self->params($serializer->flatten($params));
+}
+
+
 
 sub error_fields {
     my ($self) = @_;
@@ -1141,13 +1150,6 @@ EOF
     
     # End of Validation::Class::Errors
 
-# Random Un-documented Shortcuts
-sub errors_to_string { shift->errors->to_string(@_) }
-sub validate_group { shift->validate_groups(@_) }
-sub group_validate { shift->validate_groups(@_) }
-sub group { shift->get_group_params(@_) }
-sub param { shift->get_params(@_) }
-
 1;    # End of Validation::Class
 
 __END__
@@ -1159,7 +1161,7 @@ Validation::Class - Centralized Input Validation For Any Application
 
 =head1 VERSION
 
-version 1.112570
+version 1.112870
 
 =head1 SYNOPSIS
 
@@ -1173,6 +1175,17 @@ version 1.112570
 
 =head1 DESCRIPTION
 
+Important Note! Validation::Class just got alot more flexible which came at the
+cost of losing the grouped parameters functionality. AGAIN, grouped parameters
+are no longer supported using the old way of doing things. Validation::Class now
+supports hash serialization/deserialization which means that you can now set
+the parameters using a hashref of nested hashrefs and validate against them, or
+set the parameters using a hashref of (serialized)key/(non-ref)value pairs and
+validate against that. This function is provided in Validation::Class via
+L<Hash::Flatten>.
+
+=head1 DESCRIPTION
+
 Validation::Class is a different approach to data validation, it attempts to
 simplify and centralize data validation rules to ensure DRY (don't repeat
 yourself) code. The primary intent of this module is to provide a simplistic
@@ -1221,7 +1234,7 @@ validation work-flow and promote code (validation) reuse.
     };
     
     # a validation rule
-    field 'user:login'  => {
+    field 'user.login'  => {
         mixin      => 'basic',
         label      => 'user login',
         error      => 'login invalid',
@@ -1232,7 +1245,7 @@ validation work-flow and promote code (validation) reuse.
     };
     
     # a validation rule
-    field 'user:password'  => {
+    field 'user.password'  => {
         mixin         => 'basic',
         label         => 'user login',
         error         => 'login invalid',
@@ -1618,37 +1631,15 @@ to validate against (params must match field names).
         return $input->errors->to_string;
     }
 
-If you are using groups in your validation class you might validate your data
-like so ...
-
-    use MyApp::Validation;
-    
-    my $input = MyApp::Validation->new(params => $params);
-    unless ($input->validate('user:login', 'user:password')){
-        return $input->errors->to_string;
-    }
-
-Although this means that the incoming parameters need to specify its parameter
-names using the same group naming convention. If this is not to your liking,
-the validate() method can assist you in mapping your incoming parameters to your
-grouped validation fields as shown here:
-
-    use MyApp::Validation;
-    
-    my $input = MyApp::Validation->new(params => $params);
-    unless ($input->validate({ user => 'user:login', pass => 'user:password')){
-        return $input->errors->to_string;
-    }
-
-You can also map automatically by using field aliases whereby a field definition
-will have an alias attribute containing an arrayref of alternate parameters that
-can be matched against passed-in parameters as an alternative to the parameter
-mapping technique. The whole mapping technique can get cumbersome in larger
+You can define an alias to automatically map a parameter to a validation field
+whereby a field definition will have an alias attribute containing an arrayref
+of alternate parameters that can be matched against passed-in parameters.
+The whole mapping technique can get cumbersome in larger
 projects.
 
     package MyApp::Validation;
     
-    field 'foo:bar' => {
+    field 'foo.bar' => {
         ...,
         alias => [
             'foo',
@@ -1716,6 +1707,21 @@ directives during validation.
     $self->report_unknown(1);
     ...
 
+=head2 hash_inflator
+
+The hash_inflator value determines how the hash serializer (inflation/deflation)
+behaves. The value must be a hashref of L<Hash::Flatten/OPTIONS> options. Pure
+for the sake of consistency, you can use lowercase keys (with underscores) which
+will be converted to camelcased keys before passed to the serializer.
+
+    my $self = MyApp::Validation->new(
+        hash_inflator => {
+            hash_delimiter => '/',
+            array_delimiter => '//'
+        }
+    );
+    ...
+
 =head2 params
 
 The params attribute gets/sets the parameters to be validated.
@@ -1771,36 +1777,6 @@ passed validation checks.
         return $input->errors->to_string;
     }
 
-=head2 validate_groups
-
-If your fields and parameters are grouped using the group:field convention, The
-validate_groups method returns true/false depending on whether all specified
-*group(s) fields passed validation checks. 
-
-    use MyApp::Validation;
-    
-    my $input = MyApp::Validation->new(params => $params);
-    
-    # validate all fields within a specific group
-    unless ($input->validate_groups('person')){
-        ...
-    }
-    
-    # validate specific fields within a specific group
-    unless ($input->validate_groups('person', [qw/login password/])){
-        ...
-    }
-    
-    # validate specific fields within a specific groups
-    my @groups = (
-        person => [qw/login password/],
-        person_settings => [qw/email title/]
-    );
-    
-    unless ($input->validate_groups(@groups)){
-        ...
-    }
-
 =head2 reset_fields
 
 The reset_fields effectively resets any altered field objects at the class level.
@@ -1813,29 +1789,14 @@ This method is called automatically everytime the new() method is triggered.
 The following are convenience functions for handling your input data after
 processing and data validation.
 
-=head2 get_group_params
-
-If your fields and parameters are grouped using the group:field convention, The
-get_group_params method returns a hashref of specified parameters.
-
-    my $params = {
-        'user:login' => 'member',
-        'user:password' => 'abc123456'
-    };
-    
-    if ($self->validate_group('user')) {
-        my $user = $self->get_group_params('user');
-        print $user->{login};
-    }
-
 =head2 get_params
 
 The get_params method returns the values (in list form) of the parameters
 specified.
 
     if ($self->validate) {
-        my $name = $self->get_params('name');
-        my ($name, $email, $login, $password) =
+        my $name_a = $self->get_params('name');
+        my ($name_b, $email, $login, $password) =
             $self->get_params(qw/name email login password/);
         
         # you should note that if the params dont exist they will return undef
@@ -1852,6 +1813,39 @@ specified.
         }
     }
 
+=head2 get_params_hash
+
+If your fields and parameters are designed with complex hash structures, The
+get_params_hash method returns the deserialized hashref of specified parameters
+based on the the default or custom configuration of the hash serializer
+L<Hash::Flatten>.
+
+    my $params = {
+        'user.login' => 'member',
+        'user.password' => 'abc123456'
+    };
+    
+    if ($self->validate(keys %$params)) {
+        my $params = $self->get_params_hash;
+        print $params->{user}->{login};
+    }
+
+=head2 set_params_hash
+
+Depending on how parameters are being input into your application, if your
+input parameters are already complex hash structures, The set_params_hash method
+will set and return the serialized version of your hashref based on the the
+default or custom configuration of the hash serializer L<Hash::Flatten>.
+
+    my $params = {
+        user => {
+            login => 'member',
+            password => 'abc123456'
+        }
+    };
+    
+    my $serialized_params = $self->set_params_hash($params);
+
 =head1 ERROR HANDLING
 
 The most important part of any input validation framework is its ease-of-use and
